@@ -1,4 +1,5 @@
 import glob
+import os
 import shutil
 import subprocess
 import sys
@@ -11,11 +12,13 @@ import tomli
 from hatch_jupyter_builder.compare_migrated.cli import main
 
 HERE = Path(__file__).parent.absolute()
+REPO_ROOT = str(HERE.parent).replace(os.sep, "/")
 
 
-@pytest.mark.migration_test
+@pytest.mark.migration_test()
 def test_npm_builder_migration():
     python = sys.executable
+    os.environ["BUILDER_VERSION_SPEC"] = f"@file://{REPO_ROOT}"
     # Copy the source cookiecutter extension into two temporary directories.
     with tempfile.TemporaryDirectory() as td1, tempfile.TemporaryDirectory() as td2:
         source = HERE / "data" / "npm_builder"
@@ -37,6 +40,9 @@ def test_npm_builder_migration():
         source_hooks = source_data["tool"]["hatch"]["build"]["hooks"]
         target_hooks = target_data["tool"]["hatch"]["build"]["hooks"]
         source_hooks["jupyter-builder"] = target_hooks["jupyter-builder"]
+        # Hatchling might add some classifiers
+        del source_data["project"]["classifiers"]
+        del target_data["project"]["classifiers"]
         assert source_data == target_data
 
         # Compare the produced wheel and sdist for the migrated and unmigrated
@@ -64,9 +70,10 @@ def test_npm_builder_migration():
             subprocess.check_call([python, "-m", "twine", "check", "--strict", dist_files[0]])
 
 
-@pytest.mark.migration_test
+@pytest.mark.migration_test()
 def test_create_cmdclass_migration():
     python = sys.executable
+    os.environ["BUILDER_VERSION_SPEC"] = f"@file://{REPO_ROOT}"
     # Copy the source cookiecutter extension into two temporary directories.
     with tempfile.TemporaryDirectory() as td1, tempfile.TemporaryDirectory() as td2:
         source = HERE / "data" / "create_cmdclass"
@@ -88,6 +95,9 @@ def test_create_cmdclass_migration():
         source_hooks = source_data["tool"]["hatch"]["build"]["hooks"]
         target_hooks = target_data["tool"]["hatch"]["build"]["hooks"]
         source_hooks["jupyter-builder"] = target_hooks["jupyter-builder"]
+        # Hatchling might add some classifiers
+        del source_data["project"]["classifiers"]
+        del target_data["project"]["classifiers"]
         assert source_data == target_data
 
         # Compare the produced wheel and sdist for the migrated and unmigrated
